@@ -7,7 +7,7 @@ RDF::Trine::Graph - Materialized RDF Graphs for testing isomorphism
 
 =head1 VERSION
 
-This document describes RDF::Trine::Graph version 0.138
+This document describes RDF::Trine::Graph version 1.007
 
 =head1 SYNOPSIS
 
@@ -16,6 +16,13 @@ This document describes RDF::Trine::Graph version 0.138
   my $b	= RDF::Trine::Graph->new( $model_b );
   print "graphs are " . ($a->equals( $b ) ? "the same" : "different");
 
+=head1 DESCRIPTION
+
+RDF::Trine::Graph provdes a mechanism for testing graph isomorphism based on
+graph triples from either a RDF::Trine::Model or a RDF::Trine::Iterator.
+Isomorphism testing requires materializing all of a graph's triples in memory,
+and so should be used carefully in situations with large graphs.
+
 =head1 METHODS
 
 =over 4
@@ -33,7 +40,7 @@ use Algorithm::Combinatorics qw(permutations);
 our ($VERSION, $debug, $AUTOLOAD);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.138';
+	$VERSION	= '1.007';
 }
 
 use overload
@@ -361,13 +368,18 @@ __END__
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/perlrdf/issues>.
+
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
