@@ -7,7 +7,7 @@ RDF::Trine::Model - Model class
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model version 1.002
+This document describes RDF::Trine::Model version 1.007
 
 =head1 METHODS
 
@@ -23,7 +23,7 @@ no warnings 'redefine';
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '1.002';
+	$VERSION	= '1.007';
 }
 
 use Scalar::Util qw(blessed refaddr);
@@ -125,6 +125,22 @@ sub end_bulk_ops {
 	}
 }
 
+=item C<< logger ( [ $logger ] ) >>
+
+Returns the logging object responsible for recording data inserts and deletes.
+
+If C<< $logger >> is passed as an argument, sets the logger to this object.
+
+=cut
+
+sub logger {
+	my $self	= shift;
+	if (scalar(@_)) {
+		$self->{'logger'}	= shift;
+	}
+	return $self->{'logger'};
+}
+
 =item C<< add_statement ( $statement [, $context] ) >>
 
 Adds the specified C<< $statement >> to the rdf store.
@@ -155,6 +171,15 @@ sub add_statement {
 # 			warn "*** upgraded to a DBI store";
 		}
 	}
+	
+	if (my $log = $self->logger) {
+		my ($st, $context)	= @args;
+		if (defined($context)) {
+			$st	= RDF::Trine::Statement::Quad->new(($st->nodes)[0..2], $context);
+		}
+		$log->add($st);
+	}
+	
 	return $self->_store->add_statement( @args );
 }
 
@@ -367,7 +392,15 @@ Removes the specified C<< $statement >> from the rdf store.
 
 sub remove_statement {
 	my $self	= shift;
-	return $self->_store->remove_statement( @_ );
+	my @args	= @_;
+	if (my $log = $self->logger) {
+		my ($st, $context)	= @args;
+		if (defined($context)) {
+			$st	= RDF::Trine::Statement::Quad->new(($st->nodes)[0..2], $context);
+		}
+		$log->delete($st);
+	}
+	return $self->_store->remove_statement( @args );
 }
 
 =item C<< remove_statements ( $subject, $predicate, $object [, $context] ) >>
@@ -378,6 +411,9 @@ Removes all statements matching the supplied C<< $statement >> pattern from the
 
 sub remove_statements {
 	my $self	= shift;
+	if (my $log = $self->logger) {
+		$log->delete($_) foreach (@_);
+	}
 	return $self->_store->remove_statements( @_ );
 }
 
@@ -644,6 +680,8 @@ sub _get_pattern {
 	}
 }
 
+=item C<< get_graphs >>
+
 =item C<< get_contexts >>
 
 Returns an L<iterator|RDF::Trine::Iterator> containing the nodes representing 
@@ -662,6 +700,7 @@ sub get_contexts {
 		return $iter;
 	}
 }
+*get_graphs = \&get_contexts;
 
 =item C<< as_stream >>
 
@@ -929,18 +968,26 @@ sub bounded_description {
 # 				warn "CBD handling node " . $n->sse . "\n";
 				next if ($seen{ $n->sse });
 				try {
-					my $sts	= $self->get_statements( $n );
-					my @s	= grep { not($seen{$_->object->sse}) } $sts->get_all;
-# 					warn "+ " . $_->sse . "\n" for (@s);
-					push(@statements, @s);
+					my $st		= RDF::Trine::Statement->new( $n, map { variable($_) } qw(p o) );
+					my $pat		= RDF::Trine::Pattern->new( $st );
+					my $sts		= $self->get_pattern( $pat, undef, orderby => [ qw(p ASC o ASC) ] );
+# 					my $sts		= $stream->as_statements( qw(s p o) );
+# 					my $sts	= $self->get_statements( $n );
+					my @s	= grep { not($seen{$_->{'o'}->sse}) } $sts->get_all;
+# 					warn "+ " . $_->as_string . "\n" for (@s);
+					push(@statements, map { RDF::Trine::Statement->new($n, @{ $_ }{qw(p o)}) } @s);
 				} catch RDF::Trine::Error::UnimplementedError with {
 					$l->debug('[model] Ignored UnimplementedError in bounded_description: ' . $_[0]->{'-text'});
 				};
 				try {
-					my $sts	= $self->get_statements( undef, undef, $n );
-					my @s	= grep { not($seen{$_->subject->sse}) and not($_->subject->equal($n)) } $sts->get_all;
-# 					warn "- " . $_->sse . "\n" for (@s);
-					push(@statements, @s);
+					my $st		= RDF::Trine::Statement->new( (map { variable($_) } qw(s p)), $n );
+					my $pat		= RDF::Trine::Pattern->new( $st );
+					my $sts		= $self->get_pattern( $pat, undef, orderby => [ qw(s ASC p ASC) ] );
+# 					my $sts		= $stream->as_statements( qw(s p o) );
+# 					my $sts	= $self->get_statements( undef, undef, $n );
+					my @s	= grep { not($seen{$_->{'s'}->sse}) and not($_->{'s'}->equal($n)) } $sts->get_all;
+# 					warn "- " . $_->as_string . "\n" for (@s);
+					push(@statements, map { RDF::Trine::Statement->new(@{ $_ }{qw(s p)}, $n) } @s);
 				} catch RDF::Trine::Error::UnimplementedError with {
 					$l->debug('[model] Ignored UnimplementedError in bounded_description: ' . $_[0]->{'-text'});
 				};
