@@ -7,7 +7,14 @@ RDF::Trine::Model::Dataset - Model for SPARQL datasets
 
 =head1 VERSION
 
-This document describes RDF::Trine::Model::Dataset version 0.138
+This document describes RDF::Trine::Model::Dataset version 1.007
+
+=head1 STATUS
+
+This module's API and functionality should be considered unstable.
+In the future, this module may change in backwards-incompatible ways,
+or be removed entirely. If you need functionality that this module provides,
+please L<get in touch|http://www.perlrdf.org/>.
 
 =head1 METHODS
 
@@ -30,7 +37,7 @@ use RDF::Trine::Model;
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.138';
+	$VERSION	= '1.007';
 }
 
 ################################################################################
@@ -350,6 +357,8 @@ sub get_sparql {
 	throw RDF::Trine::Error::UnimplementedError -text => "Cannot execute SPARQL queries against a complex dataset model";
 }
 
+=item C<< get_graphs >>
+
 =item C<< get_contexts >>
 
 Returns an iterator containing the nodes representing the named graphs in the
@@ -367,6 +376,7 @@ sub get_contexts {
 		return RDF::Trine::Iterator->new( \@nodes );
 	}
 }
+*get_graphs = \&get_contexts;
 
 =item C<< model >>
 
@@ -390,13 +400,18 @@ __END__
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests to through the GitHub web interface
+at L<https://github.com/kasei/perlrdf/issues>.
+
 =head1 AUTHOR
 
 Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
