@@ -7,7 +7,7 @@ RDF::Trine::Node::Literal - RDF Node class for literals
 
 =head1 VERSION
 
-This document describes RDF::Trine::Node::Literal version 1.000
+This document describes RDF::Trine::Node::Literal version 1.007
 
 =cut
 
@@ -27,10 +27,10 @@ use Carp qw(carp croak confess);
 
 our ($VERSION, $USE_XMLLITERALS, $USE_FORMULAE);
 BEGIN {
-	$VERSION	= '1.000';
-	eval "use RDF::Trine::Node::Literal::XML;";
+	$VERSION	= '1.007';
+	eval "use RDF::Trine::Node::Literal::XML;";	## no critic (ProhibitStringyEval)
 	$USE_XMLLITERALS	= (RDF::Trine::Node::Literal::XML->can('new')) ? 1 : 0;
-	eval "use RDF::Trine::Node::Formula;";
+	eval "use RDF::Trine::Node::Formula;";	## no critic (ProhibitStringyEval)
 	$USE_FORMULAE = (RDF::Trine::Node::Formula->can('new')) ? 1 : 0;
 }
 
@@ -288,6 +288,24 @@ sub _compare {
 	return 0;
 }
 
+=item C<< canonicalize >>
+
+Returns a new literal node object whose value is in canonical form (where applicable).
+
+=cut
+
+sub canonicalize {
+	my $self	= shift;
+	my $class	= ref($self);
+	my $dt		= $self->literal_datatype;
+	my $lang	= $self->literal_value_language;
+	my $value	= $self->value;
+	if (defined $dt) {
+		$value	= RDF::Trine::Node::Literal->canonicalize_literal_value( $value, $dt, 1 );
+	}
+	return $class->new($value, $lang, $dt);
+}
+
 =item C<< canonicalize_literal_value ( $string, $datatype, $warn ) >>
 
 If C<< $datatype >> is a recognized datatype, returns the canonical lexical
@@ -566,7 +584,7 @@ sub numeric_value {
 	if ($self->is_numeric_type) {
 		my $value	= $self->literal_value;
 		if (looks_like_number($value)) {
-			my $v	= 0 + eval "$value";
+			my $v	= 0 + eval "$value";	## no critic (ProhibitStringyEval)
 			return $v;
 		} else {
 			throw RDF::Query::Error::TypeError -text => "Literal with numeric type does not appear to have numeric value.";
