@@ -4,7 +4,7 @@ RDF::Trine::Store::Dydra - RDF Store proxy for a Dydra endpoint
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Dydra version 1.000
+This document describes RDF::Trine::Store::Dydra version 1.007
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,7 @@ use RDF::Trine::Error qw(:try);
 my @pos_names;
 our $VERSION;
 BEGIN {
-	$VERSION	= "1.000";
+	$VERSION	= "1.007";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 	@pos_names	= qw(subject predicate object context);
@@ -90,7 +90,7 @@ sub new {
 	my $user	= shift;
 	my $repo	= shift;
 	my $token	= shift;
-	my $ua = LWP::UserAgent->new( agent => "RDF::Trine/${RDF::Trine::VERSION}" );
+	my $ua		= RDF::Trine->default_useragent->clone;
 	my $accept	= join(',',
 					"application/sparql-results+json",
 					"application/rdf+xml;q=0.5",
